# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#          Diego Sarmentero <diego.sarmentero@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Widget to show if we don't detect a network connection."""

import gettext

from PyQt4 import QtGui

from ubuntu_sso import networkstate

from ubuntuone_installer.gui.qt.ui import network_detection_ui

_ = gettext.gettext


class NetworkDetectionPage(QtGui.QWizardPage):

    """Widget to show if we don't detect a network connection."""

    def __init__(self, parent=None):
        super(NetworkDetectionPage, self).__init__(parent)
        self.setTitle(_("Installing Ubuntu One"))
        self.ui = network_detection_ui.Ui_Form()
        self.ui.setupUi(self)

    # pylint: disable=C0103
    def initializePage(self):
        """Set UI details."""
        self.wizard()._next_id = None

        self.setButtonText(QtGui.QWizard.CustomButton1, _("Try again"))
        self.setButtonText(QtGui.QWizard.CancelButton,
            _("Close window and set up later"))
        self.wizard().setButtonLayout([
            QtGui.QWizard.Stretch,
            QtGui.QWizard.CustomButton1,
            QtGui.QWizard.CancelButton,
            ])

        try:
            self.wizard().customButtonClicked.disconnect()
        except TypeError:
            pass

        self.wizard().customButtonClicked.connect(self.try_again)
    # pylint: enable=C0103

    def try_again(self):
        """Test the connection again."""
        d = networkstate.is_machine_connected()
        if d:
            self.wizard().next()
